@@ -1,6 +1,7 @@
 import hashlib
-from typing import Any, Set
+from typing import Set
 
+from ..hasher import HashContext
 from . import Backend
 
 
@@ -11,9 +12,13 @@ class HashlibBackend(Backend):
     def algorithms_available(self) -> Set[str]:
         return self._algorithms
 
-    def load_ctx(self, name: str) -> Any:
-        # The ``name`` has been checked in ``load_cmd``.
+    def load_ctx(self, name: str) -> HashContext:
+        # The `name` has been checked in `load_cmd`.
         try:
             return hashlib.new(name.replace("-", "_"))
         except ValueError:
             return hashlib.new(name)
+
+
+def load() -> HashlibBackend:
+    return HashlibBackend()
