@@ -16,7 +16,7 @@ from .core import (
     check_hash_line,
     generate_hash_line,
 )
-from .hasher import Hasher
+from .hasher import HashContext, Hasher
 from .utils.click import CommandX, PathWithSuffix
 from .utils.glob import glob_filters, sorted_path
 
@@ -99,7 +99,7 @@ class Gethash:
     stop: Optional[int]
     dir_ok: bool
 
-    def __init__(self, ctx: Any, **kwargs: Any) -> None:
+    def __init__(self, ctx: HashContext, **kwargs: Any) -> None:
         self.ctx = ctx
         self.sync = kwargs.pop("sync", False)
         self.suffix = kwargs.pop("suffix", ".sha")
@@ -212,13 +212,13 @@ class Gethash:
         click.secho(msg, file=self.stderr, fg="red")
 
 
-def script_main(ctx: Any, files: Tuple[str, ...], **options: Any) -> None:
+def script_main(ctx: HashContext, files: Tuple[str, ...], **options: Any) -> None:
     """Execute the body for the main function."""
 
     no_stdout = options.pop("no_stdout", False)
     no_stderr = options.pop("no_stderr", False)
-    stdout = open(os.devnull, "w") if no_stdout else sys.stdout
-    stderr = open(os.devnull, "w") if no_stderr else sys.stderr
+    stdout = open(os.devnull, "w") if no_stdout else sys.stdout  # noqa
+    stderr = open(os.devnull, "w") if no_stderr else sys.stderr  # noqa
 
     check = options.pop("check", False)
     with Gethash(ctx, stdout=stdout, stderr=stderr, **options) as gethash:
@@ -235,7 +235,7 @@ def gethashcli(command_name: str, display_name: str, **extras: Any) -> Callable[
         if doc is not None:
             func.__doc__ = doc
 
-        context_settings = dict(help_option_names=["-h", "--help"], max_content_width=120)
+        context_settings = {"help_option_names": ["-h", "--help"], "max_content_width": 120}
 
         path_format = MutuallyExclusiveOptionGroup("Path Format")
         output_mode = MutuallyExclusiveOptionGroup("Output Mode")
